==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/email/language/nb.php <==
<?php


$l['name'] = 'E-post';
$l['description'] = 'Fullverdig e-postklient. Hver bruker kan sende og motta e-post.';
$lang['link_type'][9]='E-post';
$l['feedbackNoReciepent'] = 'Du må angi en mottager!';
$l['feedbackSMTPProblem'] = 'Problemer med kommunikasjon med SMTP: ';
$l['feedbackUnexpectedError'] = 'Uventet problem ved bygging av e-post: ';
$l['feedbackCreateFolderFailed'] = 'Kunne ikke lage mappen';
$l['feedbackDeleteFolderFailed'] = 'Kunne ikke slette mappen';
$l['feedbackSubscribeFolderFailed'] = 'Kunne ikke abonnere på mappen';
$l['feedbackUnsubscribeFolderFailed'] = 'Kunne ikke deaktivere abonnement på mappen';
$l['feedbackCannotConnect'] = 'Kan ikke koble til %1$s via port %3$s<br /><br />Mailserveren returnerer: %2$s';
$l['inbox'] = 'Inbox';
$l['spam']='Søppelpost';
$l['trash']='Papirkurv';
$l['sent']='Sendt';
$l['drafts']='Utkast';
$l['no_subject']='Emne mangler';
$l['to']='Til';
$l['from']='Fra';
$l['subject']='Emne';
$l['no_recipients']='Undisclosed recipients';
$l['original_message']='--- Originalmelding følger her ---';
$l['attachments']='Vedlegg';
$l['notification_subject']='Lest: %s';
$l['notification_body']='Din e-post med emne "%s" ble vist på mottagers skjerm den %s';
$l['errorGettingMessage']='Kan ikke hente meldinger fra serveren';
$l['no_recipients_drafts']='Ingen mottagere';
$l['usage_limit'] = '%s av %s brukt';
$l['usage'] = '%s brukt';
$l['event']='Avtale';
$l['calendar']='kalender';
$l['quotaError']="Din e-postboks er full. Forsøk først å tømme papirkurven. Hvis e-postboksen fotsatt er full må du slå av papirkurven for å slette meldinger i andre mapper. Du kan slå av papirkurven under:\n\nInnstillinger -> Kontoer -> Dobbeltklikk på konto -> Mapper.";
$l['draftsDisabled']="Meldingen kan ikke lagres fordi mappen 'Utkast' er slått av.<br /><br />Gå til Innstillinger -> Kontoer -> Dobbeltklikk på konto -> Mapper for konfigurering.";
$l['noSaveWithPop3']='Meldingen kan ikke lagres fordi POP3 kontoer ikke støtter dette.';
$l['goAlreadyStarted']='Group-Office kjører allerede. E-postprogrammet er nå lastet i Group-Office. Lukk dette vinduet og skriv meldingen din i Group-Office.';
$l['replyHeader']='%s, %s kl %s skrev %s :';
$l['alias']='Alias';
$l['aliases']='Aliaser';
$l['alias']='Alias';
$l['aliases']='Aliaser';
$l['noUidNext']='Din mailserver støtter ikke UIDNEXT. Mappen \'Utkast\' er derfor automatisk slått av for denne kontoen.';
$l['disable_trash_folder']='Feil ved flytting av e-post til papirkurv. Årsaken kan være at du ikke har mer diskplass. Du kan bare frigjøre plass ved å deaktivere mappen for papirkurv på: Administrasjon -> Kontoer -> Dobbeltklikk på din konto -> Mapper';
$l['error_move_folder']='Kunne ikke flytte mappen';
$l['error_getaddrinfo']='Ugyldig serveradresse angitt';
$l['error_authentication']='Ugyldig brukernavn eller passord';
$l['error_connection_refused']='Tilkoblingen ble avvist. Kontroller server og portnummer.';
$l['iCalendar_event_invitation']='Meldingen inneholder en invitasjon til en hendelse.';
$l['iCalendar_event_not_found']='Meldingen inneholder en oppdatering av en hendelse som ikke eksisterer lenger.';
$l['iCalendar_update_available']='Meldingen inneholder en oppdatering av en eksisterende hendelse.';
$l['iCalendar_update_old']='Meldingen inneholder en hendelse som allerede er behandlet.';
$l['iCalendar_event_cancelled']='Meldingen inneholder kansellering av en hendelse.';
$l['iCalendar_event_invitation_declined']='Meldingen inneholder en invitasjon til en hendelse du har avvist.';
$l['untilDateError']='Forsøkte å behandle fram til angitt dato, men ble avbrutt på grunn av at det oppstod en feil';
$l["messages"]='Meldinger';
$l["message"]='Melding';
$l["inbox"]='Innboks';
$l["accounts"]='Kontoer';
$l["account"]='E-postkonto';
$l["crossAccountMove"]='Du kan ikke flytte meldinger til en annen konto';
$l["compose"]='Skriv';
$l["reply"]='Svar';
$l["replyAll"]='Svar alle';
$l["forward"]='Videresend';
$l["markAsRead"]='Merk som lest';
$l["markAsUnread"]='Merk som ulest';
$l["flag"]='Nytt flagg';
$l["unflag"]='Fjern flagg';
$l["flagged"]='Flagget';
$l["unflagged"]='Uflagget';
$l["root"]='Rot';
$l["folders"]='Mapper';
$l["filter"]='Filter';
$l["filters"]='Filtere';
$l["selectFolderDelete"]='Velg en mappe å slette';
$l["selectFolderAdd"]='Velg en mappe i trevisningen hvor du ønsker å legge til en ny mappe. Trykk deretter på \'Ny\'';
$l["forward"]='Videresend';
$l["resetSearch"]='Nullstill søk';
$l["emailMessage"]='E-postmelding';
$l["host"]='Server';
$l["field"]='Felt';
$l["contains"]='Inneholder';
$l["moveToFolder"]='Flytt til mappe';
$l["incomingMail"]='Innkommende e-post';
$l["advanced"]='Avansert';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Ikke sjekk gyldighet på sertifikat';
$l["port"]='Port';
$l["rootMailbox"]='Rot e-postboks';
$l["manageFolders"]='Behandle mapper';
$l["sendItemsFolder"]='Sendt';
$l["trashFolder"]='Papirkurv';
$l["draftsFolder"]='Utkast';
$l["sender"]='Fra felt';
$l["subject"]='Emne';
$l["toField"]='Til felt';
$l["ccField"]='CC felt';
$l["bccField"]='BCC felt';
$l["keyword"]='Nøkkelord';
$l["notification"]='Be om kvittering tilbake';
$l["high"]='Høy';
$l["normal"]='Normal';
$l["low"]='Lav';
$l["from"]='Fra';
$l["sendTo"]='Send til';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Velg mal';
$l["composeEmail"]='Skriv en e-post';
$l["send"]='Send';
$l["extraOptions"]='Ekstra innstillinger';
$l["attachments"]='Vedlegg';
$l["show"]='Vis';
$l["noAccount"]='Du har ikke konfigurert en e-postkonto ennå. Gå til e-post -> Kontoer for å sette opp din første e-postkonto';
$l["attachFiles"]='Legg ved filer fra din PC';
$l["uploadAttachments"]='Last opp vedlegg';
$l["startTransfer"]='Start overføring';
$l["cantEditFolder"]='Du kan ikke endre denne mappen';
$l["cantDeleteInboxFolder"]='Du kan ikke slette INNBOKS';
$l["enterFolderName"]='Angi mappenavn:';
$l["addFolder"]='Ny mappe';
$l["to"]='Til';
$l["downloadAllAsZip"]='Last ned alle som en ZIP-fil';
$l["body"]='Meldingstekst';
$l["recievedBefore"]='Mottatt før';
$l["recievedSince"]='Mottatt siden';
$l["answered"]='Besvart';
$l["unanswered"]='Ubesvart';
$l["viewed"]='Vist';
$l["outgoingMail"]='Utgående e-post';
$l["encryption"]='Kryptering';
$l["type"]='Type';
$l["noEncryption"]='Ingen kryptering';
$l["noAccountTitle"]='Ingen konto';
$l["priority"]='Prioritet';
$l["read"]='Lest';
$l["NA"]='I/A';
$l["emptyFolder"]='Tøm mappe';
$l["emptyFolderConfirm"]='Er du sikker på at du vil TØMME \'{name}\'?';
$l["addUnknownRecipients"]='Legg til ukjente mottagere';
$l["addUnknownRecipientsText"]='Du har nettopp sendt en e-post til en eller flere mottagere som ikke er i adresseboken din. Trykk på et navn hvis du vil legge til personen eller lukk dette vinduet.';
$l["attachFilesPC"]='Legg til fra PC';
$l["attachFilesGO"]='Legg til fra Group-Office';
$l["vacation"]='Automatisk svar';
$l["vacationActive"]='Slå på automatisk svar';
$l["vacationSubject"]='Emne';
$l["vacationBody"]='Meldingstekst';
$l["addToRecipients"]= 'Legg til mottagere';
$l["addToCC"]= 'Legg til CC';
$l["addToBCC"]= 'Legg til BCC';
$l["viewSource"]='Vis kildekode';
$l["sendNotification"]='Avsender har bedt om lesebekreftelse: %s. Ønsker du å sende en lesebekreftelse nå?';
$l["searchOnSender"]='Vis meldinger i gjeldende mappe';
$l["blocked"]= '{blocked_images} bilder fra andre tjenere er blokkert av sikkerhetshensyn.';
$l["unblock"]= 'Last inn bilder';
$l["loadEmailFirst"]= 'For å bruke denne funksjonen må du laste inn en e-post først ved å trykke e-postfanen';
$l["confirmEmptySubject"]='Du har ikke angitt noe emne. Er du sikker på at du vil sende denne e-posten uten å angi noe emne?';
$l["usage"]='Diskforbruk';
$l["searchGO"]='Søk gjennom Group-Office';
$l["toggleWindowPosition"]= 'Skift meldingsvinduets posisjon';
$l["closeUploadDialog"]='Lukk opplastingsvinduet først eller vent til opplasting er ferdig';
$l["signature"]='Signatur';
$l["defaultProgram"]='Forvalgt e-postprogram';
$l["defaultProgramInstructions"] ='<p>For å sette Group-Office som forvalgt e-postprogram må du <a class="normal-link" href="http://www.group-office.com/wiki/E-mail#Set_Group-Office_as_your_default_e-mail_client" target="_blank">lese instruksjonene</a>.</p><p>Hvis du bruker Windows må du også laste ned og kjøre <a class="normal-link" href="{url}">denne registerfilen</a></p>';
$l["htmlMarkup"]= 'Bruk HTML';
$l["confirmLostChanges"]= 'Endringer vil gå tapt. Er du sikker?';
$l["alias"]="Alias";
$l["aliases"]="Aliaser";
$l["accountId"]="Konto ID";
$l["email"]="E-post";
$l["signature"]="Signatur";
$l["alias"]="Alias";
$l["aliases"]="Aliaser";
$l["accountId"]="Konto ID";
$l["email"]="E-post";
$l["signature"]="Signatur";
$l["manageAliases"]='Behandle aliaser';
$l["addSendersTo"]='Legg til avsendere i ...';
$l["defaultTemplate"]='Sett valgte mal som standard';
$l["moving"]='Flytter...';
$l["selectFolderRename"]='Velg mappen du vil gi nytt navn til';
$l["cantRenameInboxFolder"]='Du kan ikke endre navnet på mappen INBOX ';
$l["renameFolder"]='Gi nytt navn til mappe';
$l["orderFilters"]='Du kan endre filterenes rekkefølge med dra og slipp.';
$l["orderAccounts"]='Du kan endre kontoenes rekkefølge med dra og slipp.';
$l["groups"]='Brukergrupper';
$l["showUnread"]='Vis uleste';
$l["searchFrom"]='Avsender';
$l["searchTo"]='Mottaker';
$l["searchCC"]='Mottaker (CC)';
$l["forwardTo"]='Videresend e-post til';
$l["youHaveNewMails"]= 'Antall nye e-poster: {new}';
$l["anyField"]='Alle felt';
$l["replaceEmailText"]='Kontakpersonen har allerede tre e-postadresser registert. Du kan erstatte en av disse ved å klikke på den du vil bytte ut.';
$l["skipUnknownRecipientsAction"]='Ikke vis dette vinduet neste gang';
$l["skipUnknownRecipients"]='Ikke vis dialogvindu for ukjente mottagere';
$l["alwaysRequestNotification"]='Krev alltid lesebekreftelse';
$l["alwaysRespondToNotifications"]='Send lesebekreftelser automatisk.';
$l["icalendarUpdateEvent"]='Oppdater hendelse';
$l["icalendarDeleteEvent"]='Slett hendelse';
$l["icalendarAcceptInvitation"]='Aksepter';
$l["icalendarDeclineInvitation"]='Avvis';
$l["icalendarTentativeInvitation"]='Tentativ';
$l["icalendarEventUpdated"]='Hendelsen er oppdatert.';
$l["icalendarEventCreated"]='Hendelsen er opprettet.';
$l["icalendarEventDeleted"]='Hendelsen er slettet.';
$l["icalendarInvitationDeclined"]='Invitasjonen er avvist.';
$l["icalendarDeleteEventConfirm"]='Er du sikker på at du vil slette denne hendelsen?';
$l["sending"]='Sender...';
$l["defaultFontSize"]= 'Standard fontstørrelse';
$l["shareFolder"]= 'Del';
$l["readPerm"]='Lese';
$l["writePerm"]='Skrive';
$l["deletePerm"]='Slette';
$l["createMailboxPerm"]='Opprett mailbox';
$l["deleteMailboxPerm"]='Slett mailbox';
$l["adminPerm"]='Administrere';
$l["deleteOldMails"]= 'Slett gamle e-poster';
$l["deleteOldMailsInstructions"]= 'Velg en dato. Hvis du deretter klikker OK vil ALLE E-POSTER som er ELDRE enn angitt dato bli SLETTET PERMANENT.';
$l["folder"]= 'Mappe';
$l["deleteOldMailsSure1"]= 'Denne handlingen kan IKKE ANGRES. Er du HELT SIKKER på at du vil slette ALLE e-poster i denne mappen, som er eldre enn ';
$l["deleteOldMailsSure2"]= '?';
$l["nDeletedMailsTxt"]= 'Antall slettede e-poster er';
$l["deletingEmails"]= 'Sletter e-poster...';
$l["everythingBefore"]= 'Alle e-poster som er eldre enn';
$l["alsoChildren"]= 'La dette også gjelde for e-poster i undermappene.';
$l["addUnknownSenders"]='Legg til ukjente avsendere';
$l["addUnknownSendersText"]='Du legger nå til valgte avsendere til en adresseliste. Først må følgende merkede avsendere legges inn i en Group-Office adressebok. Klikk på navnene for å legge dem inn eller lukk dette vinduet.';
$l["emailFiles"]='E-post filer';
$l['autolinked']='Denne e-posten ble automatisk lenket til %s';
$l['defaultProgramInstructions']='<p>For å angi {product_name} som ditt standard e-postprogram må du <a class="normal-link" href="http://www.{product_name}.com/wiki/E-mail#Set_{product_name}_as_your_default_e-mail_client" target="_blank">følge denne veiledningen</a>.</p><p>Hvis du bruker Windows må du også laste ned å kjøre <a class="normal-link" href="{url}">denne registerfilen</a></p>';
$l['xssDetected']="Denne meldingen kan ha inneholde skadelig kode. Klikk her hvis du likevel vil se meldingen.";
$l['xssMessageHidden']='Meldingen er skjult av sikkerhetshensyn';
$l['failedRecipients']='Klarte ikke å sende til';
$l['ignoreSentFolder']='Lagre svar i samme mappe som den originale meldingen';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/email/language/nb.php <==
<?php


$l['name'] = 'E-post';
$l['description'] = 'Fullverdig e-postklient. Hver bruker kan sende og motta e-post.';
$lang['link_type'][9]='E-post';
$l['feedbackNoReciepent'] = 'Du må angi en mottager!';
$l['feedbackSMTPProblem'] = 'Problemer med kommunikasjon med SMTP: ';
$l['feedbackUnexpectedError'] = 'Uventet problem ved bygging av e-post: ';
$l['feedbackCreateFolderFailed'] = 'Kunne ikke lage mappen';
$l['feedbackDeleteFolderFailed'] = 'Kunne ikke slette mappen';
$l['feedbackSubscribeFolderFailed'] = 'Kunne ikke abonnere på mappen';
$l['feedbackUnsubscribeFolderFailed'] = 'Kunne ikke deaktivere abonnement på mappen';
$l['feedbackCannotConnect'] = 'Kan ikke koble til %1$s via port %3$s<br /><br />Mailserveren returnerer: %2$s';
$l['inbox'] = 'Inbox';
$l['spam']='Søppelpost';
$l['trash']='Papirkurv';
$l['sent']='Sendt';
$l['drafts']='Utkast';
$l['no_subject']='Emne mangler';
$l['to']='Til';
$l['from']='Fra';
$l['subject']='Emne';
$l['no_recipients']='Undisclosed recipients';
$l['original_message']='--- Originalmelding følger her ---';
$l['attachments']='Vedlegg';
$l['notification_subject']='Lest: %s';
$l['notification_body']='Din e-post med emne "%s" ble vist på mottagers skjerm den %s';
$l['errorGettingMessage']='Kan ikke hente meldinger fra serveren';
$l['no_recipients_drafts']='Ingen mottagere';
$l['usage_limit'] = '%s av %s brukt';
$l['usage'] = '%s brukt';
$l['event']='Avtale';
$l['calendar']='kalender';
$l['quotaError']="Din e-postboks er full. Forsøk først å tømme papirkurven. Hvis e-postboksen fotsatt er full må du slå av papirkurven for å slette meldinger i andre mapper. Du kan slå av papirkurven under:\n\nInnstillinger -> Kontoer -> Dobbeltklikk på konto -> Mapper.";
$l['draftsDisabled']="Meldingen kan ikke lagres fordi mappen 'Utkast' er slått av.<br /><br />Gå til Innstillinger -> Kontoer -> Dobbeltklikk på konto -> Mapper for konfigurering.";
$l['noSaveWithPop3']='Meldingen kan ikke lagres fordi POP3 kontoer ikke støtter dette.';
$l['goAlreadyStarted']='Group-Office kjører allerede. E-postprogrammet er nå lastet i Group-Office. Lukk dette vinduet og skriv meldingen din i Group-Office.';
$l['replyHeader']='%s, %s kl %s skrev %s :';
$l['alias']='Alias';
$l['aliases']='Aliaser';
$l['alias']='Alias';
$l['aliases']='Aliaser';
$l['noUidNext']='Din mailserver støtter ikke UIDNEXT. Mappen \'Utkast\' er derfor automatisk slått av for denne kontoen.';
$l['disable_trash_folder']='Feil ved flytting av e-post til papirkurv. Årsaken kan være at du ikke har mer diskplass. Du kan bare frigjøre plass ved å deaktivere mappen for papirkurv på: Administrasjon -> Kontoer -> Dobbeltklikk på din konto -> Mapper';
$l['error_move_folder']='Kunne ikke flytte mappen';
$l['error_getaddrinfo']='Ugyldig serveradresse angitt';
$l['error_authentication']='Ugyldig brukernavn eller passord';
$l['error_connection_refused']='Tilkoblingen ble avvist. Kontroller server og portnummer.';
$l['iCalendar_event_invitation']='Meldingen inneholder en invitasjon til en hendelse.';
$l['iCalendar_event_not_found']='Meldingen inneholder en oppdatering av en hendelse som ikke eksisterer lenger.';
$l['iCalendar_update_available']='Meldingen inneholder en oppdatering av en eksisterende hendelse.';
$l['iCalendar_update_old']='Meldingen inneholder en hendelse som allerede er behandlet.';
$l['iCalendar_event_cancelled']='Meldingen inneholder kansellering av en hendelse.';
$l['iCalendar_event_invitation_declined']='Meldingen inneholder en invitasjon til en hendelse du har avvist.';
$l['untilDateError']='Forsøkte å behandle fram til angitt dato, men ble avbrutt på grunn av at det oppstod en feil';
$l["messages"]='Meldinger';
$l["message"]='Melding';
$l["inbox"]='Innboks';
$l["accounts"]='Kontoer';
$l["account"]='E-postkonto';
$l["crossAccountMove"]='Du kan ikke flytte meldinger til en annen konto';
$l["compose"]='Skriv';
$l["reply"]='Svar';
$l["replyAll"]='Svar alle';
$l["forward"]='Videresend';
$l["markAsRead"]='Merk som lest';
$l["markAsUnread"]='Merk som ulest';
$l["flag"]='Nytt flagg';
$l["unflag"]='Fjern flagg';
$l["flagged"]='Flagget';
$l["unflagged"]='Uflagget';
$l["root"]='Rot';
$l["folders"]='Mapper';
$l["filter"]='Filter';
$l["filters"]='Filtere';
$l["selectFolderDelete"]='Velg en mappe å slette';
$l["selectFolderAdd"]='Velg en mappe i trevisningen hvor du ønsker å legge til en ny mappe. Trykk deretter på \'Ny\'';
$l["forward"]='Videresend';
$l["resetSearch"]='Nullstill søk';
$l["emailMessage"]='E-postmelding';
$l["host"]='Server';
$l["field"]='Felt';
$l["contains"]='Inneholder';
$l["moveToFolder"]='Flytt til mappe';
$l["incomingMail"]='Innkommende e-post';
$l["advanced"]='Avansert';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Ikke sjekk gyldighet på sertifikat';
$l["port"]='Port';
$l["rootMailbox"]='Rot e-postboks';
$l["manageFolders"]='Abonnere på mapper';
$l["sendItemsFolder"]='Standardmapppe > Sendt';
$l["trashFolder"]='Standardmappe > Papirkurv';
$l["draftsFolder"]='Standardmappe > Utkast';
$l["sender"]='Fra felt';
$l["subject"]='Emne';
$l["toField"]='Til felt';
$l["ccField"]='CC felt';
$l["bccField"]='BCC felt';
$l["keyword"]='Nøkkelord';
$l["notification"]='Be om kvittering tilbake';
$l["high"]='Høy';
$l["normal"]='Normal';
$l["low"]='Lav';
$l["from"]='Fra';
$l["sendTo"]='Send til';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Velg mal';
$l["composeEmail"]='Skriv en e-post';
$l["send"]='Send';
$l["extraOptions"]='Ekstra innstillinger';
$l["attachments"]='Vedlegg';
$l["show"]='Vis';
$l["noAccount"]='Du har ikke konfigurert en e-postkonto ennå. Gå til e-post -> Kontoer for å sette opp din første e-postkonto';
$l["attachFiles"]='Legg ved filer fra din PC';
$l["uploadAttachments"]='Last opp vedlegg';
$l["startTransfer"]='Start overføring';
$l["cantEditFolder"]='Du kan ikke endre denne mappen';
$l["cantDeleteInboxFolder"]='Du kan ikke slette INNBOKS';
$l["enterFolderName"]='Angi mappenavn:';
$l["addFolder"]='Ny mappe';
$l["to"]='Til';
$l["downloadAllAsZip"]='Last ned alle som en ZIP-fil';
$l["body"]='Meldingstekst';
$l["recievedBefore"]='Mottatt før';
$l["recievedSince"]='Mottatt siden';
$l["answered"]='Besvart';
$l["unanswered"]='Ubesvart';
$l["viewed"]='Vist';
$l["outgoingMail"]='Utgående e-post';
$l["encryption"]='Kryptering';
$l["type"]='Type';
$l["noEncryption"]='Ingen kryptering';
$l["noAccountTitle"]='Ingen konto';
$l["priority"]='Prioritet';
$l["read"]='Lest';
$l["NA"]='I/A';
$l["emptyFolder"]='Tøm mappe';
$l["emptyFolderConfirm"]='Er du sikker på at du vil TØMME \'{name}\'?';
$l["addUnknownRecipients"]='Legg til ukjente mottagere';
$l["addUnknownRecipientsText"]='Du har nettopp sendt en e-post til en eller flere mottagere som ikke er i adresseboken din. Trykk på et navn hvis du vil legge til personen eller lukk dette vinduet.';
$l["attachFilesPC"]='Legg til fra PC';
$l["attachFilesGO"]='Legg til fra Group-Office';
$l["vacation"]='Automatisk svar';
$l["vacationActive"]='Slå på automatisk svar';
$l["vacationSubject"]='Emne';
$l["vacationBody"]='Meldingstekst';
$l["addToRecipients"]= 'Legg til mottagere';
$l["addToCC"]= 'Legg til CC';
$l["addToBCC"]= 'Legg til BCC';
$l["viewSource"]='Vis kildekode';
$l["sendNotification"]='Avsender har bedt om lesebekreftelse: %s. Ønsker du å sende en lesebekreftelse nå?';
$l["searchOnSender"]='Vis meldinger i gjeldende mappe';
$l["blocked"]= '{blocked_images} bilder fra andre tjenere er blokkert av sikkerhetshensyn.';
$l["unblock"]= 'Last inn bilder';
$l["loadEmailFirst"]= 'For å bruke denne funksjonen må du laste inn en e-post først ved å trykke e-postfanen';
$l["confirmEmptySubject"]='Du har ikke angitt noe emne. Er du sikker på at du vil sende denne e-posten uten å angi noe emne?';
$l["usage"]='Diskforbruk';
$l["searchGO"]='Søk gjennom Group-Office';
$l["toggleWindowPosition"]= 'Skift meldingsvinduets posisjon';
$l["closeUploadDialog"]='Lukk opplastingsvinduet først eller vent til opplasting er ferdig';
$l["signature"]='Signatur';
$l["defaultProgram"]='Forvalgt e-postprogram';
$l["defaultProgramInstructions"] ='<p>For å sette Group-Office som forvalgt e-postprogram må du <a class="normal-link" href="http://www.group-office.com/wiki/E-mail#Set_Group-Office_as_your_default_e-mail_client" target="_blank">lese instruksjonene</a>.</p><p>Hvis du bruker Windows må du også laste ned og kjøre <a class="normal-link" href="{url}">denne registerfilen</a></p>';
$l["htmlMarkup"]= 'Bruk HTML';
$l["confirmLostChanges"]= 'Endringer vil gå tapt. Er du sikker?';
$l["alias"]="Alias";
$l["aliases"]="Aliaser";
$l["accountId"]="Konto ID";
$l["email"]="E-post";
$l["signature"]="Signatur";
$l["alias"]="Alias";
$l["aliases"]="Aliaser";
$l["accountId"]="Konto ID";
$l["email"]="E-post";
$l["signature"]="Signatur";
$l["manageAliases"]='Behandle aliaser';
$l["addSendersTo"]='Legg til avsendere i ...';
$l["defaultTemplate"]='Sett valgte mal som standard';
$l["moving"]='Flytter...';
$l["selectFolderRename"]='Velg mappen du vil gi nytt navn til';
$l["cantRenameInboxFolder"]='Du kan ikke endre navnet på mappen INBOX ';
$l["renameFolder"]='Gi nytt navn til mappe';
$l["orderFilters"]='Du kan endre filterenes rekkefølge med dra og slipp.';
$l["orderAccounts"]='Du kan endre kontoenes rekkefølge med dra og slipp.';
$l["groups"]='Brukergrupper';
$l["showUnread"]='Vis uleste';
$l["searchFrom"]='Avsender';
$l["searchTo"]='Mottaker';
$l["searchCC"]='Mottaker (CC)';
$l["forwardTo"]='Videresend e-post til';
$l["youHaveNewMails"]= 'Antall nye e-poster: {new}';
$l["anyField"]='Alle felt';
$l["replaceEmailText"]='Kontakpersonen har allerede tre e-postadresser registert. Du kan erstatte en av disse ved å klikke på den du vil bytte ut.';
$l["skipUnknownRecipientsAction"]='Ikke vis dette vinduet neste gang';
$l["skipUnknownRecipients"]='Ikke vis dialogvindu for ukjente mottagere';
$l["alwaysRequestNotification"]='Krev alltid lesebekreftelse';
$l["alwaysRespondToNotifications"]='Send lesebekreftelser automatisk.';
$l["icalendarUpdateEvent"]='Oppdater hendelse';
$l["icalendarDeleteEvent"]='Slett hendelse';
$l["icalendarAcceptInvitation"]='Aksepter';
$l["icalendarDeclineInvitation"]='Avvis';
$l["icalendarTentativeInvitation"]='Tentativ';
$l["icalendarEventUpdated"]='Hendelsen er oppdatert.';
$l["icalendarEventCreated"]='Hendelsen er opprettet.';
$l["icalendarEventDeleted"]='Hendelsen er slettet.';
$l["icalendarInvitationDeclined"]='Invitasjonen er avvist.';
$l["icalendarDeleteEventConfirm"]='Er du sikker på at du vil slette denne hendelsen?';
$l["sending"]='Sender...';
$l["defaultFontSize"]= 'Standard fontstørrelse';
$l["shareFolder"]= 'Del';
$l["readPerm"]='Lese';
$l["writePerm"]='Skrive';
$l["deletePerm"]='Slette';
$l["createMailboxPerm"]='Opprett mailbox';
$l["deleteMailboxPerm"]='Slett mailbox';
$l["adminPerm"]='Administrere';
$l["folder"]= 'Mappe';
$l["deletingEmails"]= 'Sletter e-poster...';
$l["everythingBefore"]= 'Alle e-poster som er eldre enn';
$l["alsoChildren"]= 'La dette også gjelde for e-poster i undermappene.';
$l["addUnknownSenders"]='Legg til ukjente avsendere';
$l["addUnknownSendersText"]='Du legger nå til valgte avsendere til en adresseliste. Først må følgende merkede avsendere legges inn i en Group-Office adressebok. Klikk på navnene for å legge dem inn eller lukk dette vinduet.';
$l["emailFiles"]='Send filer med e-post';
$l['autolinked']='Denne e-posten ble automatisk lenket til %s';
$l['defaultProgramInstructions']='<p>For å angi {product_name} som ditt standard e-postprogram må du <a class="normal-link" href="http://www.{product_name}.com/wiki/E-mail#Set_{product_name}_as_your_default_e-mail_client" target="_blank">følge denne veiledningen</a>.</p><p>Hvis du bruker Windows må du også laste ned å kjøre <a class="normal-link" href="{url}">denne registerfilen</a></p>';
$l['xssDetected']="Denne meldingen kan ha inneholde skadelig kode. Klikk her hvis du likevel vil se meldingen.";
$l['xssMessageHidden']='Meldingen er skjult av sikkerhetshensyn';
$l['failedRecipients']='Klarte ikke å sende til';
$l['ignoreSentFolder']='Lagre svar i samme mappe som den originale meldingen';
$l["moveOldMails"]= 'Flytt eldre e-poster';
$l["moveOldMailsInstructions"]= 'Velg en dato. Når du deretter klikker OK, vil alle e-poster i valgte mappe som er eldre enn valgte dato flyttes over til angitt målmappe.';
$l["moveOldMailsSure"]= 'Er du sikker på at du vil flytte alle e-poster eldre enn {date} fra "{source}" til "{target}"?';
$l["nMovedMailsTxt"]= 'Antall flyttede e-poster er ';
$l['sourceAndTargetSame']="Kildemappe og målmappe kan ikke være samme mappe!";
$l['subscribeFolders']='Abonnére på mapper';
$l["deleteSendersFrom"]='Slett sendere fra...';
$l['imapLoginFailed']='Autensitering feilet for bruker "%username".';
$l['tryNewCredentials']='Forsøk et annet IMAP passord.';
$l['moveTo']='Flytt til';
